@@ -1,16 +1,18 @@
 # coding: utf-8
 from __future__ import absolute_import
 
-import pickle
 import argparse
 import importlib
 import logging
+import os
+import pickle
+import pkg_resources
 import re
 import shelve
+import six
 import threading
 import time
-import six
-import pkg_resources
+import yaml
 
 from . import utils
 
@@ -232,6 +234,45 @@ class Storage(object):
         self._shelve.close()
 
 
+class Config(object):
+    def read_from_file(self, filename):
+        with open(filename) as f:
+            self.read_from_string(f.read())
+
+    def read_from_string(self, data):
+        data = yaml.load(data)
+
+        # This complex code allows you
+        # to translate such YAML config:
+        #
+        # adapters: [xmpp, http]
+        # xmpp:
+        #   jid: thebot@ya.ru
+        # http:
+        #   port: 9000
+        #
+        # into a config with attributes `xmpp_jid` and `http_port`.
+        for key in ('plugins', 'adapters'):
+            for item in data.get(key, []):
+                item_settings = data.pop(item, None)
+                if item_settings is not None:
+                    for k, v in item_settings.items():
+                        data[item + '_' + k] = v
+
+
+        for key, value in data.items():
+            setattr(self, key, value)
+
+    def update_from_args(self, args):
+        """Gets settings from the Namespace object, generated by argparse."""
+        for key, value in args._get_kwargs():
+            if value is not None:
+                if key in ('adapters', 'plugins'):
+                    value = value.split(',')
+
+                setattr(self, key, value)
+
+
 class Bot(object):
     def __init__(self, command_line_args=[], adapters=None, plugins=None, config_dict={}):
         self.adapters = []
@@ -262,19 +303,36 @@ class Bot(object):
 
             return value
 
+
+        config_filename = 'thebot.conf'
+        config = Config()
+
+        config.read_from_string("""
+            adapters: [console]
+            plugins: [image]
+            unittest: no
+            storage_filename: thebot.storage
+            log_filename: thebot.log
+            verbose: no
+        """)
+
+        if os.path.exists(config_filename):
+            config.read_from_file(config_filename)
+
         parser = Bot.get_general_options()
         args, unknown = parser.parse_known_args(
             list(filter(lambda x: x not in ('--help', '-h'), command_line_args))
         )
+        config.update_from_args(args)
 
         if adapters is None:
-            adapter_classes = map(lambda a: load(a, 'Adapter'), args.adapters.split(','))
+            adapter_classes = map(lambda a: load(a, 'Adapter'), config.adapters)
         else:
             # we've got adapters argument (it is used for testing purpose
             adapter_classes = adapters
 
         if plugins is None:
-            plugin_classes = [load(a, 'Plugin') for a in  args.plugins.split(',')]
+            plugin_classes = [load(a, 'Plugin') for a in  config.plugins]
         else:
             # we've got adapters argument (it is used for testing purpose
             plugin_classes = plugins
@@ -285,8 +343,9 @@ class Bot(object):
             if hasattr(cls, 'get_options'):
                 cls.get_options(parser)
 
-        self.config = parser.parse_args(command_line_args)
-        self.config.unittest = False
+        args = parser.parse_args(command_line_args)
+        config.update_from_args(args)
+        self.config = config
 
         for key, value in config_dict.items():
             setattr(self.config, key, value)
@@ -323,25 +382,25 @@ class Bot(object):
             description='The Bot — Hubot\'s killer.'
         )
         parser.add_argument(
-            '--verbose', '-v', action='store_true', default=False,
-            help='Show more output.'
+            '--verbose', '-v', action='store_true', default=None,
+            help='Show more output. Default: False.'
         )
         parser.add_argument(
-            '--log-filename', default='thebot.log',
+            '--log-filename',
             help='Log\'s filename. Default: thebot.log.'
         )
         parser.add_argument(
-            '--storage-filename', default='thebot.storage',
-            help='Path to a database file, used for TheBot\'s memory.'
+            '--storage-filename',
+            help='Path to a database file, used for TheBot\'s memory. Default: thebot.storage.'
         )
 
         group = parser.add_argument_group('General options')
         group.add_argument(
-            '--adapters', '-a', default='console',
+            '--adapters', '-a',
             help='Adapters to use. You can specify a comma-separated list to use more than one adapter. Default: console.',
         )
         group.add_argument(
-            '--plugins', '-p', default='image',
+            '--plugins', '-p',
             help='Plugins to use. You can specify a comma-separated list to use more than one plugin. Default: image.',
         )
         return parser
